@@ -35,29 +35,29 @@ __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.12/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.20/reference/services/shield.html#Shield.Paginator.ListAttacks)
     """
 
     def paginate(
         self,
         ResourceArns: List[str] = None,
-        StartTime: TimeRangeTypeDef = None,
-        EndTime: TimeRangeTypeDef = None,
+        StartTime: "TimeRangeTypeDef" = None,
+        EndTime: "TimeRangeTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAttacksResponseTypeDef]:
         """
-        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.12/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.20/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.12/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.20/reference/services/shield.html#Shield.Paginator.ListProtections)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListProtectionsResponseTypeDef]:
         """
-        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.12/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.20/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
         """
